@@ -2,11 +2,11 @@ name = "openapi_builder"
 path = name.lower().replace("-", "_").replace(" ", "_")
 # The version number should follow https://python.org/dev/peps/pep-0440 and
 # https://semver.org
-version = "0.2.3"
+version = "0.2.4"
 author = "Patrick Vogel"
 author_email = "patrickvogel@live.nl"
 description = (
     "A Flask extension to automatically add OpenAPI documentation for your Flask app."
 )
-url = "https://github.com/FlyingBird95/openapi_builder"
+url = "https://github.com/FlyingBird95/openapi-builder"
 license = "MIT"
