@@ -1,42 +1,56 @@
-import contextlib
+import enum
+import warnings
 from typing import Any, List, Optional
 
 from flask import Flask
 from werkzeug.routing import Rule
 
-from . import util
 from .blueprint.blueprint import openapi_documentation
-from .converters.base import Converter
-from .documentation import Documentation
-from .exceptions import MissingConfigContext, MissingConverter
+from .constants import EXTENSION_NAME
+from .converters.base import CONVERTER_CLASSES, Converter
+from .converters.parameter.process import parse_openapi_arguments
+from .documentation import Documentation, DocumentationContext
+from .exceptions import MissingConverter
 from .specification import (
     Info,
     MediaType,
     OpenAPI,
     Operation,
+    Parameter,
     PathItem,
     Paths,
+    Reference,
     RequestBody,
     Response,
     Responses,
+    Schema,
     Server,
 )
+from .util import openapi_endpoint_name_from_rule
 
 
 class DocumentationOptions:
+    class StrictMode(enum.Enum):
+        FAIL_ON_ERROR = enum.auto()
+        SHOW_WARNINGS = enum.auto()
+
     def __init__(
         self,
         include_head_response: bool = True,
         include_options_response: bool = True,
         server_url: str = "/",
         include_marshmallow_converters: bool = True,
+        include_halogen_converters: bool = False,
         include_documentation_blueprint: bool = True,
+        strict_mode: StrictMode = StrictMode.SHOW_WARNINGS,
     ):
         self.include_head_response: bool = include_head_response
         self.include_options_response: bool = include_options_response
         self.server_url: str = server_url
         self.include_marshmallow_converters: bool = include_marshmallow_converters
+        self.include_halogen_converters: bool = include_halogen_converters
         self.include_documentation_blueprint: bool = include_documentation_blueprint
+        self.strict_mode: DocumentationOptions.StrictMode = strict_mode
 
 
 class OpenApiDocumentation:
@@ -52,7 +66,6 @@ class OpenApiDocumentation:
     >>> documentation = OpenApiDocumentation()
     >>> app = Flask(__name__)
     >>> documentation.init_app(app=app)
-
     """
 
     def __init__(
@@ -62,24 +75,23 @@ class OpenApiDocumentation:
         version: str = "1.0.0",
         options: Optional[DocumentationOptions] = None,
     ):
-        self.app: Optional[Flask] = app
-        """After self.init_app is called, the self.app must not be None anymore."""
+        """Initialize the extension.
 
+        :param app: The Flask application for iterating the endpoints to find out the documentation.
+        :param title: The title of the API.
+        :param version: The version of the API implementation.
+        :param options: Global documentation options for the builder.
+        """
+        self.app: Optional[Flask] = app
         self.options: DocumentationOptions = (
             options if options is not None else DocumentationOptions()
         )
-        """Global documentation options for the builder."""
-
         self.specification = OpenAPI(
             info=Info(title=title, version=version),
             paths=Paths(),
             servers=[Server(url=self.options.server_url)],
         )
-        """The specification that is generated using the builder."""
-
         self.builder = OpenAPIBuilder(open_api_documentation=self)
-        """The builder used for iterating the endpoints. This is done in order to generate the
-        configuration configuration."""
 
         if self.app is not None:
             self.init_app(app)
@@ -92,10 +104,11 @@ class OpenApiDocumentation:
         if self.options.include_documentation_blueprint:
             app.register_blueprint(openapi_documentation)
 
+        app.before_first_request(self.builder.register_converters)
         app.before_first_request(self.builder.iterate_endpoints)
 
         # Register the extension in the app.
-        app.extensions["__open_api_doc__"] = self
+        app.extensions[EXTENSION_NAME] = self
         self.app = app
 
     def get_configuration(self):
@@ -106,86 +119,76 @@ class OpenApiDocumentation:
 class OpenAPIBuilder:
     """OpenAPI builder for generating the documentation."""
 
+    documentation_context = DocumentationContext()
+
     def __init__(self, open_api_documentation: OpenApiDocumentation):
-        self.converters: List[Converter] = []
         self.open_api_documentation: OpenApiDocumentation = open_api_documentation
-        self.__documentation_config: Optional[Documentation] = None
-
-        if self.options.include_marshmallow_converters:
-            # Keep import below to support packages without marshmallow.
-            from openapi_builder.converters.marshmallow import (
-                register_marshmallow_converters,
-            )
-
-            register_marshmallow_converters(self)
+        self.converters: List[Converter] = []
 
+    @documentation_context.verify_context
     def process(self, value: Any, name: Optional[str] = None):
         """Processes an instance, and returns a schema, or reference to that schema."""
-        if self.__documentation_config is None:
-            raise MissingConfigContext()
-
-        if name in self.__documentation_config.custom_converters:
-            return self.__documentation_config.custom_converters[name]
-
-        converter = next(
-            (
-                converter
-                for converter in self.converters
-                if isinstance(value, converter.converts_class)
-            ),
-            None,
-        )
-        if converter is None:
-            raise MissingConverter(value=value)
-
-        return converter.convert(value=value)
-
-    @contextlib.contextmanager
-    def use_documentation_config(self, documentation_config: Documentation):
-        """Context manager for function that need to be executed with a documentation_config."""
-        if not isinstance(documentation_config, Documentation):
-            raise TypeError(
-                f"{documentation_config} is not an instance of Documentation."
+        try:
+            converter = next(
+                converter for converter in self.converters if converter.matches(value)
             )
+        except StopIteration:
+            if self.options.strict_mode == self.options.StrictMode.FAIL_ON_ERROR:
+                raise MissingConverter()
+            elif self.options.strict_mode == self.options.StrictMode.SHOW_WARNINGS:
+                warnings.warn(f"Missing converter for: {value}", UserWarning)
+                return Schema(example="<unknown>")
+            else:
+                raise ValueError(f"Unknown strict mode: {self.options.strict_mode}")
+        else:
+            return converter.convert(value=value)
 
-        self.__documentation_config = documentation_config
-        yield
-        self.__documentation_config = None
+    def register_converters(self):
+        """Registers converts for the instance.
+
+        This function is executed before the first request is processed the in the corresponding
+        Flask application. Also before, OpenApiBuilder.iterate_endpoints.
+        """
+        if self.options.include_marshmallow_converters:
+            # Keep import below to support packages without marshmallow.
+            import openapi_builder.converters.marshmallow  # noqa: F401
+
+        if self.options.include_halogen_converters:
+            # Keep import below to support packages without halogen.
+            import openapi_builder.converters.halogen  # noqa: F401
+
+        self.converters = [
+            converter_class(builder=self) for converter_class in CONVERTER_CLASSES
+        ]
+
+        # register parameter converters
+        import openapi_builder.converters.parameter.flask_converters  # noqa: F401
 
     def iterate_endpoints(self):
         """Iterates the endpoints of the Flask application to generate the documentation.
 
         This function is executed before the first request is processed in the corresponding
-        Flask application.
+        Flask application, but after OpenApiBuilder.register_converters.
         """
         for rule in self.open_api_documentation.app.url_map._rules:
             view_func = self.open_api_documentation.app.view_functions[rule.endpoint]
-            config: Documentation = getattr(view_func, "__open_api_doc__", None)
-            if config is None:
+            try:
+                config: Documentation = getattr(view_func, EXTENSION_NAME)
+            except AttributeError:
                 # endpoint has no documentation configuration -> skip
                 continue
 
-            with self.use_documentation_config(config):
+            with self.documentation_context.use_config(config):
                 self.process_rule(rule)
 
+    @documentation_context.verify_context
     def process_rule(self, rule: Rule):
-        """Processes a Werkzeug rule.
-
-        The function must be called within the use_documentation_config-context manager.
-        Usage:
-        >>> builder = OpenAPIBuilder()
-        >>> config = Documentation()  # retrieved from the @add_documentation decorator.
-        >>> with builder.use_documentation_config(config):
-        >>>   builder.process_rule(rule)
-        """
-        if self.__documentation_config is None:
-            raise MissingConfigContext()
-
+        """Processes a Werkzeug rule."""
         view_func = self.open_api_documentation.app.view_functions[rule.endpoint]
 
-        parameters = list(self.__documentation_config.parameters)
-        parameters.extend(util.parse_openapi_arguments(rule))
-        endpoint_name = util.openapi_endpoint_name_from_rule(rule)
+        parameters = list(self.documentation_context.config.parameters)
+        parameters.extend(parse_openapi_arguments(rule))
+        endpoint_name = openapi_endpoint_name_from_rule(rule)
 
         if endpoint_name not in self.paths.values:
             self.paths.values[endpoint_name] = PathItem(parameters=parameters)
@@ -193,31 +196,50 @@ class OpenAPIBuilder:
 
         for method in rule.methods:
             values = {}
-            for key, schema in self.__documentation_config.responses.items():
+            for key, schema in self.documentation_context.config.responses.items():
                 reference = self.process(schema)
                 values[key] = Response(
-                    description=self.__documentation_config.description
-                    or view_func.__doc__,
+                    description=(
+                        self.documentation_context.config.description
+                        or view_func.__doc__
+                    ),
                     content={"application/json": MediaType(schema=reference)},
                 )
 
-            if self.__documentation_config.input_schema is not None:
-                schema_or_reference = self.process(
-                    self.__documentation_config.input_schema
-                )
+            input_schema = self.documentation_context.config.input_schema
+            if input_schema is not None and method == "GET":
+                schema_or_reference = self.process(input_schema)
+                if isinstance(schema_or_reference, Reference):
+                    schema = schema_or_reference.get_schema(
+                        self.open_api_documentation.specification
+                    )
+                else:
+                    schema = schema_or_reference
+                for key, value in schema.properties.items():
+                    path_item.parameters.append(
+                        Parameter(
+                            in_="query",
+                            name=key,
+                            schema=value,
+                            required=value.required,
+                        )
+                    )
+                request_body = None
+            elif input_schema is not None:
+                schema_or_reference = self.process(input_schema)
                 request_body = RequestBody(
-                    description=self.__documentation_config.description,
+                    description=self.documentation_context.config.description,
                     content={"application/json": MediaType(schema=schema_or_reference)},
                 )
             else:
                 request_body = None
 
             operation = Operation(
-                summary=self.__documentation_config.summary,
-                description=self.__documentation_config.description,
+                summary=self.documentation_context.config.summary,
+                description=self.documentation_context.config.description,
                 responses=Responses(values=values),
                 request_body=request_body,
-                tags=self.__documentation_config.tags,
+                tags=self.documentation_context.config.tags,
             )
 
             if method == "GET":
@@ -231,10 +253,6 @@ class OpenAPIBuilder:
             if method == "PUT":
                 path_item.put = operation
 
-    def register_converter(self, converter):
-        """Register a converter for this builder."""
-        self.converters.append(converter)
-
     @property
     def schemas(self):
         """Helper property to return the schemas."""
